@@ -1,7 +1,7 @@
 package Module::FatPack;
 
 our $DATE = '2015-06-12'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -45,7 +45,7 @@ _
             tags => ['category:input'],
             pos => 0,
             greedy => 1,
-            'x.schema.entity' => 'modulename',
+            'x.schema.element_entity' => 'modulename',
         },
         module_srcs => {
             summary => 'Module source codes',
@@ -265,7 +265,7 @@ Module::FatPack - Generate source code that contains fatpacked modules
 
 =head1 VERSION
 
-This document describes version 0.02 of Module::FatPack (from Perl distribution Module-FatPack), released on 2015-06-12.
+This document describes version 0.03 of Module::FatPack (from Perl distribution Module-FatPack), released on 2015-06-12.
 
 =head1 SEE ALSO
 
